---
status: uner-dev
---

## Version 0.8.0

### Enhancements
- Labels can now be sorted in various way before being written to CSV, in order to reflect the ontological hierarchy flexibly. The default has changed to "ascending", meaning more specific to more generic labels (it was alphabetic before).

### Contributors
- [Johann Dreo](https://github.com/jdreo)

## Version 0.7.0

### Enhancements
- Added `Ruff` as a tool for linting/formatting, including CI.
- BioCypher has support for NetworkX.
- BioChatter has improved token statistics handling (@shaohong feng) and has received a prototypic Python API calling module as a result of the German BioHackathon 3 in December. In this hackathon, we worked on integrating BioChatter-driven API calling with the scverse ecosystem (starting with core packages anndata and scanpy). Many thanks to all who contributed in the hackathon!

### Contributors
- [Paul To](https://github.com/kpto)
- [Yaxi Liu](https://github.com/ryxx0811)
- [Shaohong Feng](https://github.com/fengsh27)
- [Sebastian Lobentanzer](https://github.com/slobentanzer)
- [Edwin Carreño](https://github.com/ecarrenolozano)
